aboutsummaryrefslogtreecommitdiffstats
path: root/server/src/main
diff options
context:
space:
mode:
authorDenis Anisimov <denis@vaadin.com>2016-08-18 16:24:17 +0300
committerVaadin Code Review <review@vaadin.com>2016-08-19 08:15:38 +0000
commit9b2b19366c77f164dbb54d057373713a02447984 (patch)
tree8e73e8f11047b033f5c71c7fa70d08078f2084ce /server/src/main
parente7b9db54a5aa172509b33746d270ac375009b4a6 (diff)
downloadvaadin-framework-9b2b19366c77f164dbb54d057373713a02447984.tar.gz
vaadin-framework-9b2b19366c77f164dbb54d057373713a02447984.zip
CustomField migration to new AbstractField (#61).
Change-Id: I33dd7aa2cf91ba2606a602c8ba612bcc30b02622
Diffstat (limited to 'server/src/main')
-rw-r--r--server/src/main/java/com/vaadin/legacy/ui/LegacyCustomField.java158
-rw-r--r--server/src/main/java/com/vaadin/ui/CustomField.java25
2 files changed, 166 insertions, 17 deletions
diff --git a/server/src/main/java/com/vaadin/legacy/ui/LegacyCustomField.java b/server/src/main/java/com/vaadin/legacy/ui/LegacyCustomField.java
new file mode 100644
index 0000000000..4ef634e69b
--- /dev/null
+++ b/server/src/main/java/com/vaadin/legacy/ui/LegacyCustomField.java
@@ -0,0 +1,158 @@
+/*
+ * Copyright 2000-2016 Vaadin Ltd.
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License"); you may not
+ * use this file except in compliance with the License. You may obtain a copy of
+ * the License at
+ *
+ * http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
+ * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
+ * License for the specific language governing permissions and limitations under
+ * the License.
+ */
+
+package com.vaadin.legacy.ui;
+
+import java.io.Serializable;
+import java.util.Iterator;
+
+import com.vaadin.data.Property;
+import com.vaadin.ui.Component;
+import com.vaadin.ui.HasComponents;
+import com.vaadin.v7.ui.LegacyAbstractField;
+import com.vaadin.v7.ui.LegacyField;
+
+/**
+ * A {@link LegacyField} whose UI content can be constructed by the user,
+ * enabling the creation of e.g. form fields by composing Vaadin components.
+ * Customization of both the visual presentation and the logic of the field is
+ * possible.
+ *
+ * Subclasses must implement {@link #getType()} and {@link #initContent()}.
+ *
+ * Most custom fields can simply compose a user interface that calls the methods
+ * {@link #setInternalValue(Object)} and {@link #getInternalValue()} when
+ * necessary.
+ *
+ * It is also possible to override {@link #validate()},
+ * {@link #setInternalValue(Object)}, {@link #commit()},
+ * {@link #setPropertyDataSource(Property)}, {@link #isEmpty()} and other logic
+ * of the field. Methods overriding {@link #setInternalValue(Object)} should
+ * also call the corresponding superclass method.
+ *
+ * @param <T>
+ * field value type
+ *
+ * @since 7.0
+ */
+public abstract class LegacyCustomField<T> extends LegacyAbstractField<T>
+ implements HasComponents {
+
+ /**
+ * The root component implementing the custom component.
+ */
+ private Component root = null;
+
+ /**
+ * Constructs a new custom field.
+ *
+ * <p>
+ * The component is implemented by wrapping the methods of the composition
+ * root component given as parameter. The composition root must be set
+ * before the component can be used.
+ * </p>
+ */
+ public LegacyCustomField() {
+ // expand horizontally by default
+ setWidth(100, Unit.PERCENTAGE);
+ }
+
+ /**
+ * Constructs the content and notifies it that the {@link LegacyCustomField}
+ * is attached to a window.
+ *
+ * @see com.vaadin.ui.Component#attach()
+ */
+ @Override
+ public void attach() {
+ // First call super attach to notify all children (none if content has
+ // not yet been created)
+ super.attach();
+
+ // If the content has not yet been created, create and attach it at
+ // this point by calling getContent()
+ getContent();
+ }
+
+ /**
+ * Returns the content (UI) of the custom component.
+ *
+ * @return Component
+ */
+ protected Component getContent() {
+ if (null == root) {
+ root = initContent();
+ root.setParent(this);
+ }
+ return root;
+ }
+
+ /**
+ * Create the content component or layout for the field. Subclasses of
+ * {@link LegacyCustomField} should implement this method.
+ *
+ * Note that this method is called when the CustomField is attached to a
+ * layout or when {@link #getContent()} is called explicitly for the first
+ * time. It is only called once for a {@link LegacyCustomField}.
+ *
+ * @return {@link Component} representing the UI of the CustomField
+ */
+ protected abstract Component initContent();
+
+ // Size related methods
+ // TODO might not be necessary to override but following the pattern from
+ // AbstractComponentContainer
+
+ @Override
+ public void setHeight(float height, Unit unit) {
+ super.setHeight(height, unit);
+ markAsDirtyRecursive();
+ }
+
+ @Override
+ public void setWidth(float width, Unit unit) {
+ super.setWidth(width, unit);
+ markAsDirtyRecursive();
+ }
+
+ // ComponentContainer methods
+
+ private class ComponentIterator
+ implements Iterator<Component>, Serializable {
+ boolean first = (root != null);
+
+ @Override
+ public boolean hasNext() {
+ return first;
+ }
+
+ @Override
+ public Component next() {
+ first = false;
+ return getContent();
+ }
+
+ @Override
+ public void remove() {
+ throw new UnsupportedOperationException();
+ }
+ }
+
+ @Override
+ public Iterator<Component> iterator() {
+ return new ComponentIterator();
+ }
+}
diff --git a/server/src/main/java/com/vaadin/ui/CustomField.java b/server/src/main/java/com/vaadin/ui/CustomField.java
index 4985560b3e..b36cb053a6 100644
--- a/server/src/main/java/com/vaadin/ui/CustomField.java
+++ b/server/src/main/java/com/vaadin/ui/CustomField.java
@@ -19,34 +19,25 @@ package com.vaadin.ui;
import java.io.Serializable;
import java.util.Iterator;
-import com.vaadin.data.Property;
-import com.vaadin.v7.ui.LegacyAbstractField;
-import com.vaadin.v7.ui.LegacyField;
+import com.vaadin.data.HasValue;
/**
* A {@link LegacyField} whose UI content can be constructed by the user,
* enabling the creation of e.g. form fields by composing Vaadin components.
* Customization of both the visual presentation and the logic of the field is
* possible.
- *
+ * <p>
* Subclasses must implement {@link #getType()} and {@link #initContent()}.
- *
+ * <p>
* Most custom fields can simply compose a user interface that calls the methods
- * {@link #setInternalValue(Object)} and {@link #getInternalValue()} when
- * necessary.
- *
- * It is also possible to override {@link #validate()},
- * {@link #setInternalValue(Object)}, {@link #commit()},
- * {@link #setPropertyDataSource(Property)}, {@link #isEmpty()} and other logic
- * of the field. Methods overriding {@link #setInternalValue(Object)} should
- * also call the corresponding superclass method.
+ * {@link #doSetValue(Object)} and {@link #getValue()} when necessary.
*
* @param <T>
* field value type
*
- * @since 7.0
+ * @since 8.0
*/
-public abstract class CustomField<T> extends LegacyAbstractField<T>
+public abstract class CustomField<T> extends AbstractField<T>
implements HasComponents {
/**
@@ -19,34 +19,25 @@ package com.vaadin.ui;
/**
- * A {@link LegacyField} whose UI content can be constructed by the user,
- * enabling the creation of e.g. form fields by composing Vaadin components.
+ * A {@link HasValue} whose UI content can be constructed by the user, enabling
+ * the creation of e.g. form fields by composing Vaadin components.
* Customization of both the visual presentation and the logic of the field is
* possible.